# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class EligibilityState(str, Enum):
    """
    EligibilityState
    """

    """
    allowed enum values
    """
    PROCESSING = 'processing'
    COMPLETED = 'completed'
    ERROR = 'error'

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityState:
        """Create an instance of EligibilityState from a JSON string"""
        return EligibilityState(json.loads(json_str))


