# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr

class EligibilityApiResponseError(BaseModel):
    """
    Details about any error that occurred during the request. (Only first error)  # noqa: E501
    """
    type: Optional[StrictStr] = Field(default=None, description="The type of error.")
    code: Optional[StrictStr] = Field(default=None, description="The error code.")
    message: Optional[StrictStr] = Field(default=None, description="A message describing the error.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["type", "code", "message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseError:
        """Create an instance of EligibilityApiResponseError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseError:
        """Create an instance of EligibilityApiResponseError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseError.parse_obj(obj)

        _obj = EligibilityApiResponseError.parse_obj({
            "type": obj.get("type"),
            "code": obj.get("code"),
            "message": obj.get("message")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


