# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ScanCaptureType(str, Enum):
    """
    ScanCaptureType
    """

    """
    allowed enum values
    """
    MANUAL = 'manual'
    AUTOMATIC = 'automatic'
    SELECTEDFILE = 'selectedFile'
    API = 'api'

    @classmethod
    def from_json(cls, json_str: str) -> ScanCaptureType:
        """Create an instance of ScanCaptureType from a JSON string"""
        return ScanCaptureType(json.loads(json_str))


